@@ -10,9 +10,10 @@ NumericMatrix parseMsSegSites(std::ifstream &output,
                               const int individuals);
                               
 NumericMatrix parseSeqgenSegSites(std::ifstream &output,
-                                  const size_t loci_length,
+                                  size_t locus_length,
                                   const size_t individuals,
-                                  NumericVector &positions);
+                                  NumericVector &position,
+                                  const NumericVector trio_opts);
 
 void addToJsfs(const NumericMatrix &seg_sites,
                const NumericVector &sample_size,
@@ -23,6 +24,12 @@ void addToFpc(const NumericMatrix &seg_sites,
               const NumericVector &breaks_near,
               const NumericVector &breaks_far,
               NumericMatrix &fpc);
+              
+void addToPolymClasses(const NumericMatrix seg_sites,
+                       const NumericVector sample_size,
+                       NumericVector &polym_classes);
+                            
+NumericVector createPolymVector();
 
 std::string line;
 
@@ -35,9 +42,14 @@ List parseOutput(const std::string file_name,
                  const bool generate_seg_sites = false,
                  const bool generate_fpc = false,
                  const NumericVector fpc_breaks_near = NumericVector(0),
-                 const NumericVector fpc_breaks_far = NumericVector(0)) {
+                 const NumericVector fpc_breaks_far = NumericVector(0),
+                 const NumericVector trio_opts = NumericVector(0),
+                 const bool generate_polym_classes = false) {
   
-  if ((!generate_seg_sites) && (!generate_jsfs) && (!generate_fpc)) return List::create();
+  if (!(generate_seg_sites || generate_jsfs || 
+              generate_fpc || generate_polym_classes)) {
+    return List::create();            
+  }
 
   //Rprintf("File: %s \n", file_name.c_str());
   std::ifstream output(file_name.c_str(), std::ifstream::in);
@@ -59,6 +71,7 @@ List parseOutput(const std::string file_name,
   List seg_sites_list(loci_number); 
   NumericMatrix jsfs(sample_size[0]+1, sample_size[1]+1);
   NumericMatrix fpc(fpc_breaks_near.size()+2, fpc_breaks_far.size()+2);
+  NumericVector polym_classes = createPolymVector();
 
   // ms
   if (program == 0) { 
@@ -71,6 +84,9 @@ List parseOutput(const std::string file_name,
         if (generate_seg_sites) seg_sites_list[locus] = seg_sites;
         if (generate_fpc) addToFpc(seg_sites, positions, 
                                    fpc_breaks_near, fpc_breaks_far, fpc);
+        if (generate_polym_classes) {
+          addToPolymClasses(seg_sites, sample_size, polym_classes);
+        }
       } 
 
       else if (line.substr(0, 9) == "segsites:") {
@@ -83,6 +99,9 @@ List parseOutput(const std::string file_name,
         if (generate_jsfs) addToJsfs(seg_sites, sample_size, jsfs);
         if (generate_fpc) addToFpc(seg_sites, positions, 
                                    fpc_breaks_near, fpc_breaks_far, fpc);
+        if (generate_polym_classes) {
+          addToPolymClasses(seg_sites, sample_size, polym_classes);
+        }
       }
     }
   }
@@ -101,12 +120,16 @@ List parseOutput(const std::string file_name,
         std::stringstream(line) >> total_sample_size >> locus_length;
         
         seg_sites = parseSeqgenSegSites(output, locus_length, 
-                                        total_sample_size, positions);
+                                        total_sample_size, positions,
+                                        trio_opts);
         
         if (generate_seg_sites) seg_sites_list[locus] = seg_sites;
         if (generate_jsfs) addToJsfs(seg_sites, sample_size, jsfs);
         if (generate_fpc) addToFpc(seg_sites, positions, 
                                    fpc_breaks_near, fpc_breaks_far, fpc);
+        if (generate_polym_classes) {
+          addToPolymClasses(seg_sites, sample_size, polym_classes);
+        }
       } else {
         stop("Unexpected line in seq-gen output.");
       }
@@ -117,37 +140,15 @@ List parseOutput(const std::string file_name,
   }
 
   output.close();
-
-  // Return the summary statistics as list without growing it
-  if (generate_seg_sites & (!generate_jsfs) & (!generate_fpc)) {
-    return List::create( _["seg.sites"] = seg_sites_list );
-  }
-  else if ((!generate_seg_sites) & generate_jsfs & (!generate_fpc)) {
-    return List::create( _["jsfs"] = jsfs );
-  }
-  else if ((!generate_seg_sites) & (!generate_jsfs) & (generate_fpc)) {
-    return List::create( _["fpc"] = fpc );
-  }
-
-  else if (generate_seg_sites & generate_jsfs & (!generate_fpc)) {
-    return List::create( _["seg.sites"] = seg_sites_list,
-                         _["jsfs"] = jsfs );
-  }
-  else if (generate_seg_sites & (!generate_jsfs) & (generate_fpc)) {
-    return List::create( _["seg.sites"] = seg_sites_list, 
-                         _["fpc"] = fpc );
-  }
-  else if ((!generate_seg_sites) & generate_jsfs & (generate_fpc)) {
-    return List::create( _["jsfs"] = jsfs, 
-                         _["fpc"] = fpc );
-  }
-
-  else {
-    return List::create( _["seg.sites"] = seg_sites_list,
-                         _["jsfs"] = jsfs, 
-                         _["fpc"] = fpc );
-  }
-
+  
+  // Return the summary statistics
+  List sum_stats;
+  
+  if (generate_seg_sites) sum_stats["seg.sites"] = seg_sites_list;
+  if (generate_jsfs) sum_stats["jsfs"] = jsfs;
+  if (generate_fpc) sum_stats["fpc"] = fpc;
+  if (generate_polym_classes) sum_stats["polym_classes"] = polym_classes;
+  return sum_stats;
 }
 
 NumericMatrix parseMsSegSites(std::ifstream &output, 
@@ -171,9 +172,10 @@ NumericMatrix parseMsSegSites(std::ifstream &output,
 
 
 NumericMatrix parseSeqgenSegSites(std::ifstream &output,
-                                  const size_t locus_length,
+                                  size_t locus_length,
                                   const size_t individuals,
-                                  NumericVector &position) {
+                                  NumericVector &position,
+                                  const NumericVector trio_opts) {
 
   std::string tmp;
   size_t seq_nr;
@@ -199,7 +201,6 @@ NumericMatrix parseSeqgenSegSites(std::ifstream &output,
   std::vector<double> positions;
   size_t derived_count;
   
-
   for (size_t j=0; j<locus_length; ++j) {
     derived_count = 0;
     for (size_t i=0; i<individuals-1; ++i) {
@@ -221,9 +222,26 @@ NumericMatrix parseSeqgenSegSites(std::ifstream &output,
       }
     }
   
-    for (std::vector<double>::iterator it = positions.begin(); it != positions.end(); ++it) {
-      *it /= (locus_length - 1);
-   }
+    if (trio_opts.size() != 5) {
+      for (std::vector<double>::iterator it = positions.begin(); 
+           it != positions.end(); ++it) {
+        *it /= (locus_length - 1);
+      }
+    } else {
+      locus_length = sum(trio_opts);
+      size_t offset = 0, locus = 0, locus_end = trio_opts[0];
+      for (std::vector<double>::iterator it = positions.begin(); 
+        it != positions.end(); ++it) {
+        while(*it >= locus_end) {
+          ++locus;
+          offset += trio_opts[locus];   // Increase offset that locus 1 + 3
+          ++locus;
+          locus_end += trio_opts[locus]; // Increase locus end at 2+4
+        }
+        *it += offset;
+        *it /= (locus_length - 1);
+      }
+    }
   
     List dimnames = List(2);
     position = wrap(positions);
